@@ -1,10 +1,9 @@
-package Syntax::Keyword::Assert 0.12;
+package Syntax::Keyword::Assert 0.13;
 
 use v5.14;
 use warnings;
 
 use Carp ();
-use Devel::StrictMode;
 
 require XSLoader;
 XSLoader::load( __PACKAGE__, our $VERSION );
@@ -38,11 +37,6 @@ sub apply {
    Carp::croak "Unrecognised import symbols @{[ keys %syms ]}" if keys %syms;
 }
 
-# called from Assert.xs
-sub _croak {
-    goto &Carp::croak;
-}
-
 1;
 __END__
 
@@ -56,13 +50,9 @@ Syntax::Keyword::Assert - assert keyword for Perl with zero runtime cost in prod
 
     use Syntax::Keyword::Assert;
 
-    sub hello($name) {
-        assert { defined $name };
-        say "Hello, $name!";
-    }
-
-    hello("Alice"); # => Hello, Alice!
-    hello();        # => Dies when STRICT mode is enabled
+    my $name = 'Alice';
+    assert( $name eq 'Bob' );
+    # => Assertion failed ("Alice" eq "Bob")
 
 =head1 DESCRIPTION
 
@@ -72,7 +62,11 @@ Syntax::Keyword::Assert introduces a lightweight assert keyword to Perl, designe
 
 =item B<STRICT Mode>
 
-When STRICT mode is enabled, assert statements are checked at runtime. If the assertion fails (i.e., the block returns false), the program dies with an error. This is particularly useful for catching errors during development or testing.
+When STRICT mode is enabled, assert statements are checked at runtime. Default is enabled. If the assertion fails (i.e., the block returns false), the program dies with an error. This is particularly useful for catching errors during development or testing.
+
+C<$ENV{PERL_ASSERT_ENABLED}> can be used to control STRICT mode.
+
+    BEGIN { $ENV{PERL_ASSERT_ENABLED} = 0 }  # Disable STRICT mode
 
 =item B<Zero Runtime Cost>
 
@@ -80,48 +74,12 @@ When STRICT mode is disabled, the assert blocks are completely ignored at compil
 
 =item B<Simple Syntax>
 
-The syntax is straightforward—assert BLOCK—making it easy to integrate into existing code.
+The syntax is dead simple. Just use the assert keyword followed by a block that returns a boolean value.
+
+    assert( $name eq 'Bob' );
 
 =back
 
-=head2 STRICT Mode Control
-
-The behavior of STRICT mode is controlled by the L<Devel::StrictMode> module. You can enable or disable STRICT mode depending on your environment (e.g., development, testing, production).
-
-For example, to enable STRICT mode:
-
-    BEGIN { $ENV{PERL_STRICT} = 1 }  # Enable STRICT mode
-
-    use Syntax::Keyword::Assert;
-    use Devel::StrictMode;
-
-    assert { 1 == 1 };  # Always passes
-    assert { 0 == 1 };  # Dies if STRICT mode is enabled
-
-To disable STRICT mode (it is disabled by default):
-
-    use Syntax::Keyword::Assert;
-    use Devel::StrictMode;
-
-    assert { 0 == 1 };  # Block is ignored, no runtime cost
-
-SEE ALSO:
-L<Bench | https://github.com/kfly8/Syntax-Keyword-Assert/blob/main/bench/compare-no-assertion.pl>
-
-=head1 TIPS
-
-=head2 Verbose error messages
-
-If you set C<$Carp::Verbose = 1>, you can see stack traces when an assertion fails.
-
-    use Syntax::Keyword::Assert;
-    use Carp;
-
-    assert {
-        local $Carp::Verbose = 1;
-        0;
-    }
-
 =head1 SEE ALSO
 
 =over 4
